| Title: | Estimation of Gas Properties from the Lennard-Jones Potential |
|---|---|
| Description: | Calculation of gas transport properties (viscosity, diffusion, thermal conductivity) using Chapman-Enskok theory (Chapman 1918, <doi:10.1098/rsta.1918.0005>) and of the second virial coefficient (Vargas et al. 2001, <doi:10.1016/s0378-4371(00)00362-9>) using the Lennard-Jones (12-6) potential. Up to the third order correction is taken into account for viscosity and thermal conductivity. It is also possible to calculate the binary diffusion coefficients of polar and non-polar gases in non-polar bath gases (Brown et al. 2011, <doi:10.1016/j.pecs.2010.12.001>). 16 collision integrals are calculated with four digit accuracy over the reduced temperature range [0.3, 400] using an interpolation function of Kim and Monroe (2014, <doi:10.1016/j.jcp.2014.05.018>). |
| Authors: | Stefan Langenberg [aut, cre] (ORCID: <https://orcid.org/0000-0001-5817-5469>) |
| Maintainer: | Stefan Langenberg <[email protected]> |
| License: | GPL-3 |
| Version: | 0.5 |
| Built: | 2026-06-04 11:51:42 UTC |
| Source: | https://github.com/langenbergstefan/chapensk |
Calculation of gas transport properties (viscosity, diffusion, thermal conductivity) using Chapman-Enskok theory (Chapman 1918, <doi:10.1098/rsta.1918.0005>) and of the second virial coefficient (Vargas et al. 2001, <doi:10.1016/s0378-4371(00)00362-9>) using the Lennard-Jones (12-6) potential. Up to the third order correction is taken into account for viscosity and thermal conductivity. It is also possible to calculate the binary diffusion coefficients of polar and non-polar gases in non-polar bath gases (Brown et al. 2011, <doi:10.1016/j.pecs.2010.12.001>). 16 collision integrals are calculated with four digit accuracy over the reduced temperature range [0.3, 400] using an interpolation function of Kim and Monroe (2014, <doi:10.1016/j.jcp.2014.05.018>).
Transport properties, such as viscosity, diffusion and thermal conductivity, play a crucial role in the modeling of combustion processes and chemical reactions. They depend on the intermolecular potential. In practice it is not necessary to have a detailed calculation of the intermolecular potential for the calculation of transport properties.
The interaction between spherical gas particles without a dipole moment can be described by the Lennard-Jones potential. It is given by the following equation:
where is the distance between two interacting particles, ε is the depth of the potential well and σ is the distance at which the
particle-particle potential energy is zero. The theory of van der Waals interaction gives the exponent 6 for the attractive term (London, 1937).
The 12 exponent in the repulsive term is largely a matter of computational practicality, though it does represent the general nature of Pauli repulsion.
The Lennard-Jones potential only can be used for non-polar molecules, but sometimes is also used for polar molecules. However, for the latter the Stockmayer (12-6-3) potential is more appropriate (Mourits and Rummens, 1977).
For monoatomic gases σ and ε are independent of temperature. However, for non-monoatomic gases, averaging over different orientations and vibrational states gives temperature dependent parameters σ and ε (Zarkova and Hohm, 2002). The temperature dependency is simplified in this package as follows by a linear temperature coefficient ζ:
The Chapman-Enskog theory is a theoretical framework used to describe the transport properties of gases, such as viscosity, thermal conductivity, and diffusion coefficients. The theory is based on the idea that the properties of a gas can be related to the collisional interactions between individual gas molecules (Chapman 1918).
Collision integrals are mathematical expressions that arise in the Chapman-Enskog theory. They quantify the effects of molecular collisions on the transport properties of a gas.
An object-oriented framework has been developed to calculate transport properties from potential parameters and vice versa. A class Gas has been defined for the calculation of the properties of gas. To facilitate calculations, a data set gas is provided for the properties of some common gases. The CollisionIntegral class is used to calculate collision integrals using an interpolation function and fit parameters from data set coefficients_collisionintegral.
Lennard-Jones parameters of non-polar molecules can be estimated using high quality of viscosity and second virial coefficients. This is demonstrated for ethane, see data set ethane_data. For polar molecules Lennard-Jones parameters for the van der Waals interaction part can be estimated from measurements of binary diffusion coefficients, see data set binary_diffusion.
| Symbol | Description | Unit | Global variable |
|
temperature coefficient of diffusion | - |
|
|
second virial coefficient | m3
|
|
|
diffusion coefficient | m2/2
|
|
|
Boltzmann constant | J/K |
pkg.env$k
|
|
molecular mass | kg
|
|
|
relative molecular mass | -
|
|
|
Avogadro constant | 1/mol |
pkg.env$Na |
|
mole | mol
|
|
|
pressure | Pa
|
|
|
standard pressure 101325 Pa | Pa |
pkg.env$p0 |
|
critical pressure | Pa
|
|
|
gas constant | J/(K.mol) |
pkg.env$R |
|
temperature | K
|
|
|
standard temperature 273.15 K | K |
pkg.env$T0 |
|
critical temperature | K
|
|
|
gas volume | m3
|
|
|
polarizability | Ao3
|
|
|
reduced polarizability | -
|
|
|
dynamic viscosity | Pa.s
|
|
|
permittivity of vacuum | F/m |
pkg.env$eps0 |
|
depth of potential well | J
|
|
|
thermal conductivity | W/(m.K)
|
|
|
dipole moment | D
|
|
|
reduced dipole moment | -
|
|
|
reduced collision integral | -
|
|
|
gas density | kg/m3
|
|
|
critical density | mol/l
|
|
|
reduced temperature | -
|
|
|
distance at which the potential energy is zero | Ao
|
|
|
scaling parameter | -
|
|
|
temperature coefficient of σ | Ao/K
|
Physical units are displayed in UCUM notation.
Stefan Langenberg [aut, cre] (ORCID: <https://orcid.org/0000-0001-5817-5469>)
Maintainer: Stefan Langenberg <[email protected]>
Brown NJ, Bastien LAJ, Price PN. Transport properties for combustion modeling. Progress in Energy and Combustion Science 2011;37:565-82. doi:10.1016/j.pecs.2010.12.001.
Chapman SV. On the kinetic theory of a gas. Part II. A composite monatomic gas: diffusion, viscosity, and thermal conduction. Philosophical Transactions of the Royal Society of London. Series A 1918;217:11597. doi:10.1098/rsta.1918.0005.
London F. The general theory of molecular forces. Transactions of the Faraday Society 1937;33:8b. doi:10.1039/tf937330008b.
Mourits FM, Rummens FHA. A critical evaluation of Lennard-Jones and Stockmayer potential parameters and of some correlation methods. Can. J. Chem. 1977;55:300720. doi:10.1139/v77-418.
Zarkova L, Hohm U. pVT-Second Virial Coefficients , Viscosity η and Self-Diffusion of the Gases: BF3, CF4,
SiF4, CCl4, SiCl4, SF6, MoF6, WF6, UF6, C(CH3)4, and Si(CH3)4 Determined by Means of an Isotropic Temperature-Dependent Potential.
Journal of Physical and Chemical Reference Data 2002;31:183216. doi:10.1063/1.1433462.
Reference data of binary diffusion coefficients for comparison with calculated diffusion coefficients. Diffusion coefficients were determined using a reversed-flow gas chromatography system.
data("binary_diffusion")data("binary_diffusion")
A data frame with 139 observations on the following 6 variables.
doiDOI of data source
bath_gasBath gas: helium, hydrogen, nitrogen
gasDiffusing species: argon, butane, difluoromethane, ethane, fluoromethane, methane, nitrogen, propane, sulfur dioxide, trifluoromethane
TTemperature in K
DDiffusion coefficient in cm2/s
U_DUncertainty of diffusion coefficient in cm2/s
Plot of experimental diffusion coefficient vs. temperature. (a) diffusion of nitrogen and
argon in helium. (b) diffusion of methane, ethane, propane and butane in helium. (c) diffusion of methane, ethane, propane and butane in nitrogen.
(d) diffusion of sulfur dioxide in hydrogen, helium and nitrogen. The solid lines are calculated using the Lennard-Jones model.
The Lennard-Jones parameters are taken from data set gas.
The diffusion coefficient as function of pressure in a narrow temperature range close to the reference temperature is usually expressed as
(Langenberg et al. 2020)
For the experimental data, the temperature coefficient is obtained from the fit. For the calculated diffusion coefficients, the temperature coefficient is
calculated by numerical derivation by
The diffusion coefficients are calculated using Gas-class. The deviation is calculated by
| Gas | Bath gas | Experimental | Calculated | Deviation | ||
/ [cm2/s] |
|
/ [cm2/s]
|
|
|||
| nitrogen | helium | 0.605(3) | 1.664(8) | 0.620 | 1.68 | -3% |
| argon | helium | 0.630(2) | 1.665(6) | 0.640 | 1.68 | -2% |
| methane | helium | 0.575(3) | 1.675(7) | 0.597 | 1.68 | -4% |
| ethane | helium | 0.421(5) | 1.68(2) | 0.446 | 1.70 | -6% |
| propane | helium | 0.341(7) | 1.67(2) | 0.361 | 1.70 | -7% |
| n-butane | helium | 0.294(6) | 1.65(2) | 0.368 | 1.74 | -32% |
| methane | nitrogen | 0.201(2) | 1.74(2) | 0.186 | 1.83 | 7% |
| ethane | nitrogen | 0.136(2) | 1.70(2) | 0.123 | 1.87 | 7% |
| propane | nitrogen | 0.106(2) | 1.72(3) | 0.094 | 1.88 | 7% |
| n-butane | nitrogen | 0.090(1) | 1.72(2) | 0.084 | 1.97 | -8% |
| sulfur dioxide | hydrogen | 0.45(2) | 1.77(6) | 0.492 | 1.85 | -14% |
| sulfur dioxide | helium | 0.41(2) | 1.7(1) | 0.490 | 1.71 | -14% |
| sulfur dioxide | nitrogen | 0.112(3) | 1.76(5) | 0.113 | 1.91 | -8% |
The values in brackets indicate the uncertainties (0.95 confidence level) of the fit parameters. With the exception of the diffusion of butane in helium, the calculated diffusion coefficients resemble the measured diffusion coefficients within an error limit of < 15%. For larger non spherical molecules like butane in helium more advanced combining rules need to be applied (Li et al. 2023).
Plot of experimental diffusion coefficient vs. temperature of fluoromethane,
difluoromethane and trifluoromethane in nitrogen. The Lennard-Jones parameters are estimated by nonlinear regression using optim
from experimental data.
The experimental data for the diffusion coefficients of fluoromethanes can in turn be used to estimate the Lennard-Jones parameters for the Van der Waals interaction. The values for ε obtained from diffusion data are smaller than ε obtained from data of viscosity measurements (Shibasaki-Kitakawa et. al. 1995, Clifford et al. 1979).
| Gas | / [cm2/s] |
|
Viscosity | Diffusion | ||
/ [Ao]
|
/ [K] |
/ [Ao]
|
/ [K] |
|||
| fluoromethane | 0.1576(7) | 1.784(8) | -- | -- | 3.5 | 174 |
| difluoromethane | 0.133(2) | 1.76(2) | 4.9 | 204 | 3.9 | 153 |
| trifluoromethane | 0.123(2) | 1.73(2) | 4.4 | 182 | 4.5 | 63 |
This is due to the fact that the fluoromethanes have a dipole moment. Thus, the well depth of the potential is higher, compared to the only van der Waals interaction. This is why the intermolecular interaction of polar molecules cannot be described in terms of the Lennard-Jones potential.
McGivern WS, Manion JA. Extending reversed-flow chromatographic methods for the measurement of diffusion coefficients to higher temperatures. J. Chromatogr. A 2011; 1218:8432-42. doi:10.1016/j.chroma.2011.09.035.
McGivern WS, Manion JA. Hydrocarbon binary diffusion coefficient measurements for use in combustion modeling. Combustion and Flame 2012;159:3021-6. doi:10.1016/j.combustflame.2012.04.015.
McGivern WS, Manion J. Binary Diffusion Coefficients for Methane and Fluoromethanes in Nitrogen. Journal of Chemical & Engineering Data 2021; 66:304756. doi:10.1021/acs.jced.1c00161.
Tsaousoglou DP, Georgiadou E, Gavril D. Determination of Sulfur Dioxide Diffusion Coefficients in Hydrogen, Helium, and Nitrogen by Reversed-Flow Inverse Gas Chromatography. J. Chem. Eng. Data 2022; 67:28728. doi:10.1021/acs.jced.2c00223.
Clifford AA, Gray P, Scott AC. Viscosities of CFCl3, CF3Cl, CHFCl2, CHF2Cl and CHF3 from 373 to 570 K. J. Chem. Soc., Faraday Trans. 1, 1979;75:1752. doi:10.1039/F19797501752
Langenberg S, Carstens T, Hupperich D, Schweighoefer S, Schurath U. Technical note: Determination of binary gas-phase diffusion coefficients of unstable and adsorbing atmospheric trace gases at low temperature arrested flow and twin tube method. Atmospheric Chemistry and Physics 2020;20:366982. doi:10.5194/acp-20-3669-2020.
Li Y, Gui Y, You X. On the binary diffusion coefficients of n-alkanes in He/N2. Combustion and Flame 2023;257:112795. doi:10.1016/j.combustflame.2023.112795.
Shibasaki-Kitakawa N, Takahashi M, Yokoyama C, Takahashi S. Gas Viscosity of Difluoromethane from 298.15 to 423.15 K and up to 10 MPa J. Chem. Eng. Data 1995; 40:900-902 doi:10.1021/je00020a036
# binary diffusion data of nitrogen in bath gas helium nitrogen_in_helium <- subset(binary_diffusion,(gas=="nitrogen" & bath_gas=="helium")) print(nitrogen_in_helium)# binary diffusion data of nitrogen in bath gas helium nitrogen_in_helium <- subset(binary_diffusion,(gas=="nitrogen" & bath_gas=="helium")) print(nitrogen_in_helium)
Coefficients for "CollisionIntegral", Table 1 from Kim and Monroe (2014).
data("coefficients_collisionintegral")data("coefficients_collisionintegral")
lorder of collision integral
sorder of collision integral
Amodel parameter
B1model parameter
B2model parameter
B3model parameter
B4model parameter
B5model parameter
B6model parameter
C1model parameter
C2model parameter
C3model parameter
C4model parameter
C5model parameter
C6model parameter
Kim SU, Monroe CW. High-accuracy calculations of sixteen collision integrals for Lennard-Jones (12-6) gases and their interpolation to parameterize neon, argon, and krypton. Journal of Computational Physics 2014;273:35873. doi:10.1016/j.jcp.2014.05.018.
"CollisionIntegral"
Class for the empirical interpolation functions for 16 reduced Lennard-Jones (12-6) collision integrals
in the range 0.3 <= Θ <= 400.
Collision integrals as function of reduced temperature Θ
l:order of collision integral
s:order of collision integral
coeff:coefficients for collision integrals for order and , see data set coefficients_collisionintegral
A:model parameter A
B:model parameter B1 ... B6
C:model parameter C1 ... C6
initialize(s, l):Initialize reduced collision integral of order and
Omega(Theta):Calculates reduced collision integral Ω(l,s) at reduced temperature using the empirical interpolation function
Kim SU, Monroe CW. High-accuracy calculations of sixteen collision integrals for Lennard-Jones (12-6) gases and their interpolation to parameterize neon, argon, and krypton. Journal of Computational Physics 2014;273:35873. doi:10.1016/j.jcp.2014.05.018.
O11 <- CollisionIntegral(l=1,s=1) O11$Omega(0.3)O11 <- CollisionIntegral(l=1,s=1) O11$Omega(0.3)
Reference values for the second virial coefficient and viscosity of ethane from a intermolecular potential energy surface. The second virial coefficient was calculated semiclassically by means of the Mayer-sampling Monte Carlo technique, while the transport properties were obtained using the classical kinetic theory of polyatomic gases. The computed thermophysical property values are in excellent agreement with the best available experimental data and are recommended as reference values.
data("ethane_data")data("ethane_data")
A data frame with 107 observations on the following 4 variables.
TTemperature in K
propertyType of property. B: classically calculated second virial coefficient, BQFH: second virial coefficient calculated by a modification of the pair potential known as the quadratic Feynman-Hibbs (QFH)
effective pair potential. viscosity: gas phase viscosity
unita factor with levels cm3/mol, uPa.s
valuenumerical value of property. For the second virial coefficient the calculated data are supported by experimental data in the temperature range 220 - 623 K. For the viscosity the calculated data are supported by experimental data in the temperature range 90 - 675 K.
(a) Viscosity of ethane. (b) second virial coefficient of ethane. The black solid curves are fits using viscosity data and second virial coefficient data
respectively. The red dotted curves are simultaneous fits against the viscosity and second virial coefficient data.
| Type of fit | σ | ε |
| vs. viscosity data | 4.38(2) | 235(6) |
| vs. second virial coefficient data | 4.95(6) | 202(3) |
| vs. viscosity and second virial coefficient data | 4.35 | 244 |
Hellmann R. Reference Values for the Second Virial Coefficient and Three Dilute Gas Transport Properties of Ethane from a State-of-the-Art Intermolecular Potential Energy Surface. Journal of Chemical & Engineering Data 2018;63:470-81. doi:10.1021/acs.jced.7b01069.
## Not run: c2h6 <- Gas("ethane") # estimate LJ-coefficients from viscosity data ethane_viscosity <- subset(ethane_data, (property=="viscosity") & (T>=90) & (T<=675), select=c(T, value) ) c2h6$dsigma_dt <- 0 ethane_viscosity$value <- 1E-6*ethane_viscosity$value c2h6$fit_viscosity_data(ethane_viscosity) print(c2h6$sigma) print(c2h6$epsk) # estimate LJ-coefficients from second virial coefficient ethane_B <- subset(ethane_data, (property=="BQFH") & (T>= 220) & (T<=623)) ethane_B$value <- 1E-6*ethane_B$value c2h6$fit_B_data(ethane_B) print(c2h6$sigma) print(c2h6$epsk) ## End(Not run)## Not run: c2h6 <- Gas("ethane") # estimate LJ-coefficients from viscosity data ethane_viscosity <- subset(ethane_data, (property=="viscosity") & (T>=90) & (T<=675), select=c(T, value) ) c2h6$dsigma_dt <- 0 ethane_viscosity$value <- 1E-6*ethane_viscosity$value c2h6$fit_viscosity_data(ethane_viscosity) print(c2h6$sigma) print(c2h6$epsk) # estimate LJ-coefficients from second virial coefficient ethane_B <- subset(ethane_data, (property=="BQFH") & (T>= 220) & (T<=623)) ethane_B$value <- 1E-6*ethane_B$value c2h6$fit_B_data(ethane_B) print(c2h6$sigma) print(c2h6$epsk) ## End(Not run)
Physical properties of some gas species.
data("gas")data("gas")
A data frame with properties of 47 gases on the following 12 variables.
formulachemical formula
namechemical name
CASChemical abstracts registry number
groupMdipole_momentelectric dipole moment in Debye
polarizabilityelectric polarizability in Ao
IEionization energy in eV
Tccritical temperature in K
pccritical pressure in bar
rhoccritical density in mol/l
sigmadistance at which the intermolecular potential between the two particles is zero in Ao
epskWell depth of the Lennard-Jones potential in K
DOIData source of Lennard-Jones parameters. If not specified otherwise, they are taken from Poling et al. (2004)
Properties of simple gases for the calculation of transport properties. Not all properties are given for all molecules. Correlations exists between the Lennard-Jones parameters and critical data as derived from numerous numerical simulations of the Lennard-Jones fluid (Stephan et al. 2019): ε and σ can be determined from critical temperature
critical density
and critical pressure
where is the Boltzmann constant.
Correlation of Lennard-Jones parameters of nonpolar gases with critical data: The solid lines are the
expectations from numerical simulations of the Lennard-Jones Fluid.
(a) critical temperature vs. well depth . (b) critical density vs.
NIST Chemistry WebBook. NIST Standard Reference Database, vol. 69, 2023. doi:10.18434/T4D303.
NIST. Experimental Polarizabilites. in: III RDJ, editor. NIST Computational Chemistry Comparison and Benchmark Database, NIST; 2020. doi:10.18434/T47C7Z.
Poling BE, Prausnitz JM, OConnell JP. The Properties of Gases and Liquids. 5 ed. New York: McGraw-Hill; 2004.
Stephan S, Thol M, Vrabec J, Hasse H. Thermophysical Properties of the Lennard-Jones Fluid: Database and Data Assessment. Journal of Chemical Information and Modeling 2019;59:424865. doi:10.1021/acs.jcim.9b00620.
"Gas"
Reference class for gas with methods for the estimation of transport properties. The equations for the higher order corrections are taken from Kim and Monroe 2014. The second virial coefficient is calculated using the equation given by Vargas et al. 2001.
name:Chemical name
M:relative molecular mass
m:Mass of one gas particle in kg
sigma:Lennard-Jones Parameter σ at
zeta:Change of σ with temperature. For the noble gases . Due to the vibrational excitation of molecules, σ is not independent of temperature but increasing with .
If is σ at , σ at is given by .
epsk:Well depth of the Lennard-Jones potential at in K.
dipole_moment:dipole moment in Debye.
polarizability:polarizability in Ao3.
check():Checks for presence of required data.
B(T):Second virial coefficient in units m3/mol. The second virial coefficient provides systematic corrections
to the ideal gas law.
The second virial coefficient depends only on the pair interaction between the particles (Vargas et. al. 2001).
It is calculated from the modified Bessel function (BesselI):
density(p=p0,T=T0):Gas density in units kg/m3 incorporating the second virial correction.
diffusion(p=p0, T=T0, second_order_correction=TRUE):Calculates the self diffusion coefficient in m2/s.
is the second order correction term. If third_order_correction=FALSE this term is set to 1.
thermal_conductivity(T, third_order_correction=TRUE):Calculates the thermal conductivity for a monoatomic gas in W/(m.K).
is the third order correction term. If third_order_correction=FALSE this term is set to 1.
For a polyatomic gas the thermal conductivity can be calculated from the expression for a monoatomic gas using the classical Eucken correction (Bechtel et al. 2020)
where is the molar heat capacity of the polyatomic gas at constant volume.
viscosity(T,third_order_correction=TRUE):The viscosity is given gas as
is the third order correction term. If third_order_correction=FALSE this term is set to 1.
binary_diffusion(p=p0, T=T0, bathGas):Binary Diffusion coefficient of gas 1 in a bath gas 2 bathGas. The gas 1 may be polar or nonpolar. The bath gas 2 must be nonpolar (Brown et al. 2010,
Langenberg et al. 2020).
The binary diffusion coefficient is given as
The influence of the dipole moment of the gas is treated by the scaling parameter (Brown et al. 2011)
where the reduced dipole moment is given by
and the reduced polarizability of the bath gas is given by
The scaling parameter is used in the following combination rules to calculate the well depth of the effective interaction potential
and the collision diameter
The second order correction (Marrero and Mason 1972) is not considered yet. Therefore, the diffusion coefficient of a polar gas in a non-polar bath gas is equal to the diffusion coefficient of a non-polar gas in a polar bath gas. For diffusion of a polar gas in a polar bath gas, this formula cannot be used.
fit_B_data(B_df):Determination of Lennard-Jones parameters σ and ε by nonlinear regression from a data frame of second virial coefficient data. The data frame must contain the columns
T for the temperature and value for the viscosity in units cm3/mol.
fit_viscosity_data(viscosity_df):Determination of Lennard-Jones parameters σ and ε by nonlinear regression from a data frame of viscosity data. The data frame must contain the columns T for the
temperature and value for the viscosity in units uPa.s.
fit_B_viscosity_data(B_df, viscosity_df, log=FALSE):Determination of Lennard-Jones parameters σ and ε by simultaneous nonlinear regression from a data frame of viscosity data and a data frame of second virial
coefficient data using optim.
If log=FALSE the function to be minimized is given by (Bechtel et. al. 2020)
where
and
If log=TRUE the function to be minimized is given by (Zarkova and Hohm 2009)
Bechtel S, Bayer B, Vidakovic-Koch T, Wiser A, Vogel H, Sundmacher K. Precise determination of LJ parameters and Eucken correction factors for a more accurate modeling of transport properties in gases. Heat and Mass Transfer 2020;56:2515-27. doi:10.1007/s00231-020-02871-4.
Brown NJ, Bastien LAJ, Price PN. Transport properties for combustion modeling. Progress in Energy and Combustion Science 2011;37:56582. doi:10.1016/j.pecs.2010.12.001.
Kim SU, Monroe CW. High-accuracy calculations of sixteen collision integrals for Lennard-Jones (12-6) gases and their interpolation to parameterize neon, argon, and krypton. Journal of Computational Physics 2014 273:358-73, doi:10.1016/j.jcp.2014.05.018.
Langenberg S, Carstens T, Hupperich D, Schweighoefer S, Schurath U. Technical note: Determination of binary gas-phase diffusion coefficients of unstable and adsorbing atmospheric trace gases at low temperature arrested flow and twin tube method. Atmospheric Chemistry and Physics 2020;20:366982. doi:10.5194/acp-20-3669-2020.
Marrero TR, Mason EA. Gaseous Diffusion Coefficients. J. Phys. Chem. Ref. Data 1972;1:3-118. doi:10.1063/1.3253094.
Vargas P, Munoz E, Rodriguez L. Second virial coefficient for the Lennard-Jones potential. Physica A: Statistical Mechanics and Its Applications 2001;290:92-100. doi:10.1016/s0378-4371(00)00362-9.
Zarkova L, Hohm U. Effective (n-6) Lennard-Jones Potentials with Temperature-Dependent Parameters Introduced for Accurate Calculation of Equilibrium and Transport Properties of Ethene, Propene, Butene, and Cyclopropane. Journal of Chemical & Engineering Data 2009;54:164855. doi:10.1021/je800733b.
## Not run: # Second virial coefficient of methane at 300 K and standard pressure CH4 <- Gas("methane") print(CH4$B(T=300)) # Self-diffusion coefficient at 300 K print(CH4$diffusion(T=300)) # create an instance of Gas for a molecule not listed in data_frame gas Hg <- Gas("mercury") # relative molecular mass Hg$M <- 200.59 # mass of 1 molecule in kg Hg$m <- Hg$M / pkg.env$Na / 1000 Hg$sigma <- 2.969 Hg$epsk <- 750 print(Hg$thermal_conductivity(T=700)) ## End(Not run)## Not run: # Second virial coefficient of methane at 300 K and standard pressure CH4 <- Gas("methane") print(CH4$B(T=300)) # Self-diffusion coefficient at 300 K print(CH4$diffusion(T=300)) # create an instance of Gas for a molecule not listed in data_frame gas Hg <- Gas("mercury") # relative molecular mass Hg$M <- 200.59 # mass of 1 molecule in kg Hg$m <- Hg$M / pkg.env$Na / 1000 Hg$sigma <- 2.969 Hg$epsk <- 750 print(Hg$thermal_conductivity(T=700)) ## End(Not run)